from setuptools import setup

setup(
    name="okome-lib",
    version="1.1.2",
    install_requires=["requests"],  
    description="m.kuku.lu wrapper",
    long_description=open("README.txt").read(),
    url="https://github.com/AntiTikTok/Okome-Lib",
)